waveformtools — waveformtools 2022-05-03 documentation

# waveformtools

Module for the analysis and handling of numerical relativity and gravitational waveform data.

## Classes

sim: Base class for NR simulations data.

  This is needed to retrieve and handle Numerical Relativity data.

spherical_array: A 2D data-type.

  Stores and manages two-dimensional data on surfaces of spherical topology.

modes_array: A data-type.

  Handle and work with mode coefficients.

Functions

`get_version`() | Get the latest version number based on the last commit date.

waveformtools.get_version()

  Get the latest version number based on the last commit date.

Modules

`waveformtools.BMS` | The implementation of BMS transformations on the waveforms.
`waveformtools.CoM` | Centre of mass correction for the waveforms.
`waveformtools.compare` | Compare the waveforms and modes
`waveformtools.dataIO` | Functions for handling data IO operations from waveforms class
`waveformtools.diagnostics` | Diagnostic tools
`waveformtools.differentiate`(data[, delta_t, TS]) | Differentiate a timeseries in time domain using the Simple Euler method
`waveformtools.extrapolate` | Methods for waveform extrapolation.
`waveformtools.grids` | Classes to hold grid information
`waveformtools.integrate` | Methods to integrate functions
`waveformtools.simulations` | Data container for Numerical Relativity data
`waveformtools.spherical` | Methods to handle functions on a sphere.
`waveformtools.transforms` | Methods to transform the waveform
`waveformtools.waveforms` | Classes for handling the waveform modes or data defined on spheres.
`waveformtools.waveformtools` | This module contains a set of tools to handle data from numerical relativity simulations and gravitational waves.